## About Healthcare/IO Parser

The Halthcare/IO **parser** is an Electronic Data Interchange (EDI) parser developed at Vanderbilt University Medical Center during Khanhly Nguyen's summer internship 2019. Built in a healthcare setting, the parser focuses (for now) on x12 claims (837) and remittances (835)

This code is intended to extract x12 837 and 835 and format them into portable and human readable format (JSON). This allows the claims to be stored in document data stores such as Mongodb, couchdb or databases that have support for JSON like PostgreSQL

We wrote this frame to be used in both command line or as a library within in your code. The framework is driven by configurations that derviced from X12 standards.

## Features ## 
    | Features | |
    |----------|-|
## Installation

    pip install --upgrade git+https://hiplab.mc.vanderbilt.edu/git/lab/parse-edi.git

## Usage 

**cli :**

        # signup to get parsing configuration
        healthcare-io.py --signup <email> [--store <mongo|sqlite>]
        
        #
        # start parsing claims in a folder
        healthcare-io.py --parse <claims|remits> --folder <path> [--batch <n>] [--resume]
        
        with :
            --parse     tells the engine what to parse claims or remits
            --folder    location of the claims|remits
            --batch     number of processes to spawn to parse the files
            --resume    tells the parser to resume parsing 
                        if all files weren't processed or new files were added into the folder
**dashboard**
    There is a built-in dashboard that has features
    healthcare-io.py --server <port> [--context <name>]    
**Embedded in Code   :**

Use **parse-edi** within your code base as a library and handle storing data in a data store of choice

    import edi.parser
    import json
    import os


    ROOT = 'data'
    CLAIMS_FOLDER = os.sep.join([ROOT,'837'])   #-- data/837    contains all 837 formatted files
    CONFIG_FOLDER = os.sep.join([ROOT,'config'])#-- data/config contains 837.json or 835.json
    
    
    files       = os.listdir(CLAIMS_FOLDER)
    filename    = os.sep.join([CLAIM_FOLDER,files[0]]) #-- selecting the first file in the folder (it's an example)
    conf        = json.loads(open( os.sep.join([CONFIG_FOLDER,'837.json']) ).read())
    info        = edi.parser.get_content(file,conf) #-- array of objects claims/remits

## Credits


* [Khanhly Nguyen] (<khanhly.t.nguyen@gmail.com>)
* [Gaylon Stanley] (<gaylon.stanley@vanderbilt.edu>)
* [Cheng Gao] (<cheng.gao@vanderbilt.edu>)
* [Brad Malin] (brad.malin@vanderbilt.edu)
* [Steve L. Nyemba] (<steve.l.nyemba@vanderbilt.edu>)



